@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id$
+$Id: interfaces.py 50798 2008-02-21 11:05:27Z cray $
 """
 __author__  = "SergeyAlembekov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision$"
+__version__ = "$Revision: 50798 $"
  
 from zope.interface import Interface
 
@@ -23,6 +23,13 @@ class IRegistryTextLine(Interface):
             description = u'',
             default = u'',
             required = False)
+
+class IRegistryText(Interface):
+    data = Text(
+            title = u'Value of textual parameter',
+            description = u'',
+            default = u'',
+            required = False)
                             
 class IRegistryInt(Interface):
     data = Int(
