@@ -2,11 +2,11 @@
 #######################################################################
 """Adapter any context to IRegistry interface
 
-$Id: registryadapter.py 49941 2008-02-06 15:18:18Z cray $
+$Id: registryadapter.py 50798 2008-02-21 11:05:27Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49941 $"
+__version__ = "$Revision: 50798 $"
 
 from zope.interface import Interface
 from ng.app.registry.interfaces import IRegistry
@@ -16,8 +16,6 @@ def RegistryAdapter(context) :
     d = {}
     n = 0
     for name,registry in getUtilitiesFor(IRegistry,context=context) :
-        print 1,name,registry
-
         if name not in d :
             n+=1
             d[name] = (registry,n)
@@ -26,7 +24,6 @@ def RegistryAdapter(context) :
             del d[registry.parent]            
 
     if d :
-        print d
         di = d.itervalues()
         registry, num = di.next()
         for item, n in di :
