@@ -26,7 +26,7 @@ class RegistryNamespace(object) :
         self.request = request
 
     def traverse(self,name,ignored) :
-        nm = name.split(':')
+        nm = name.split(':',1)
         try:
             return IRegistry(self.context).param(*nm)
         except TypeError,msg:
